Description Usage Arguments Value Author(s)
Predict method for unsupervisedForest class
1 2 |
object |
an unsupervisedForest object, |
newdata |
data to predict proximity and probability based from an unsupervisedForest |
... |
... |
a list with the following components
proximity |
proximity vector for newdata |
probability |
probability of belonging to normal or synthethic data |
David Navega
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.