Description Usage Arguments Value Author(s) See Also
Wrapper for creating unsupervised randomForest objects with prediction capabilities
1 | unsupervisedForest(x, mtry, ntree = 500, type = "data", ...)
|
x |
a data.frame. |
mtry |
an integer, defines number of variables to try at each split. |
ntree |
number of trees composing the forest. |
type |
the type of envelope used to generate random data. Default is "data". type can be "data" or "uniform". |
... |
additional parameters to the randomForest |
an unsupervisedForest object
David Navega
randomForest
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.