Description Usage Arguments Value Author(s) See Also Examples
Missing Value Imputation through randomForest Proximity Matrix
1 2 3 4 |
x |
a data.frame. |
y |
a numeric or factor vector. |
method |
type of procedure for imputation. Default is "proximity" for proximity based imputation. "missForest" triggers a hybrid technique using missForest and proximity based imputation. |
initial |
a character defining how initial missing values are imputed. Default is "mode" for mode imputation. "random" for random imputation from marginal distribution of each feature. |
mtry |
number of varibles to try at each split. |
ntree |
number of trees. |
iterations |
number of iterations used to update imputed values. |
mcar |
amount of missing values to induced completely at random. Used compute cross-validation imputation error. |
crossvalidation |
a logical indicating whether cross-validation should be made or not. Default is TRUE. |
kfold |
number of fold in cross-validation. Default is 5. |
verbose |
a logical indicating if output should be more detailed. |
seed |
a positive integer defining the seed for the random number generator. |
... |
additional arguments for randomForest |
an object of class imputeForest
David Navega
randomForest
1 2 3 4 | x <- iris[, -5]
y <- iris$Species
x_na <- induce_missing(x)
print(imputeForest(x = x_na, y = y))
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.